nbdev_cards
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

A deck of cards demo of nbdev

## Install

``` sh
pip install nbdev-cards
```

python has problemn with \_

## How to use

this lib provides a Card class for you to create display and compare
cards

``` python
Card(1,3)
```

    3♦

suits are numbered accourding to this list

``` python
suits
```

    ['♣', '♦', '♥', '♠']
